# error-pages

![Version: 1.1.2](https://img.shields.io/badge/Version-1.1.2-informational?style=flat-square) ![AppVersion: 2.6.0](https://img.shields.io/badge/AppVersion-2.6.0-informational?style=flat-square)

Server error pages in the docker image

**This chart is not maintained by the upstream project and any issues with the chart should be raised [here](https://github.com/k8s-at-home/charts/issues/new/choose)**

## Source Code

* <https://github.com/tarampampam/error-pages>

## Requirements

Kubernetes: `>=1.16.0-0`

## Dependencies

| Repository | Name | Version |
|------------|------|---------|
| https://library-charts.k8s-at-home.com | common | 4.4.2 |

## TL;DR

```console
helm repo add k8s-at-home https://k8s-at-home.com/charts/
helm repo update
helm install error-pages k8s-at-home/error-pages
```

## Installing the Chart

To install the chart with the release name `error-pages`

```console
helm install error-pages k8s-at-home/error-pages
```

## Uninstalling the Chart

To uninstall the `error-pages` deployment

```console
helm uninstall error-pages
```

The command removes all the Kubernetes components associated with the chart **including persistent volumes** and deletes the release.

## Configuration

Read through the [values.yaml](./values.yaml) file. It has several commented out suggested values.
Other values may be used from the [values.yaml](https://github.com/k8s-at-home/library-charts/tree/main/charts/stable/common/values.yaml) from the [common library](https://github.com/k8s-at-home/library-charts/tree/main/charts/stable/common).

Specify each parameter using the `--set key=value[,key=value]` argument to `helm install`.

```console
helm install error-pages \
  --set env.TZ="America/New York" \
    k8s-at-home/error-pages
```

Alternatively, a YAML file that specifies the values for the above parameters can be provided while installing the chart.

```console
helm install error-pages k8s-at-home/error-pages -f values.yaml
```

## Custom configuration

For use with Traefik you will also need to create a `IngressRoute` and `Middleware`, see the examples below:

```yaml
---
apiVersion: traefik.containo.us/v1alpha1
kind: IngressRoute
metadata:
  name: error-pages
  namespace: networking
spec:
  entryPoints:
    - websecure
  routes:
    - kind: Rule
      match: HostRegexp(`{host:.+}`)
      priority: 1
      services:
        - kind: Service
          name: error-pages
          port: 8080
  tls:
    secretName: error-pages-tls
```

```yaml
---
apiVersion: traefik.containo.us/v1alpha1
kind: Middleware
metadata:
  name: error-pages
  namespace: networking
spec:
  errors:
    status:
      - "400-599"
    query: /{status}.html
    service:
      name: error-pages
      port: 8080
```

## Values

**Important**: When deploying an application Helm chart you can add more values from our common library chart [here](https://github.com/k8s-at-home/library-charts/tree/main/charts/stable/common)

| Key | Type | Default | Description |
|-----|------|---------|-------------|
| env | object | See below | environment variables. See the [error-pages documentation](https://github.com/tarampampam/error-pages/wiki/HTTP-server) for more info. |
| env.SHOW_DETAILS | string | `"false"` | Enable details on error pages |
| env.TEMPLATE_NAME | string | `"l7-dark"` | Set the template |
| env.TZ | string | `"UTC"` | Set the container timezone |
| image.pullPolicy | string | `"IfNotPresent"` | image pull policy |
| image.repository | string | `"ghcr.io/tarampampam/error-pages"` | image repository |
| image.tag | string | `"2.6.0"` | image tag |
| ingress.main | object | See values.yaml | Enable and configure ingress settings for the chart under this key. |
| persistence | object | See values.yaml | Configure persistence settings for the chart under this key. |
| service.main.ports.http.port | int | `8080` |  |

## Changelog

### Version 1.1.2

#### Added

N/A

#### Changed

* Upgraded `common` chart dependency to version 4.4.2

#### Fixed

N/A

### Older versions

A historical overview of changes can be found on [ArtifactHUB](https://artifacthub.io/packages/helm/k8s-at-home/error-pages?modal=changelog)

## Support

- See the [Docs](https://docs.k8s-at-home.com/our-helm-charts/getting-started/)
- Open an [issue](https://github.com/k8s-at-home/charts/issues/new/choose)
- Ask a [question](https://github.com/k8s-at-home/organization/discussions)
- Join our [Discord](https://discord.gg/sTMX7Vh) community

----------------------------------------------
Autogenerated from chart metadata using [helm-docs v0.1.1](https://github.com/k8s-at-home/helm-docs/releases/v0.1.1)
