# nginx-php

![Version: 1.1.2](https://img.shields.io/badge/Version-1.1.2-informational?style=flat-square) ![AppVersion: 2.4.0](https://img.shields.io/badge/AppVersion-2.4.0-informational?style=flat-square)

Nginx and PHP FPM for running PHP applications

**This chart is not maintained by the upstream project and any issues with the chart should be raised [here](https://github.com/k8s-at-home/charts/issues/new/choose)**

## Source Code

* <https://github.com/TrafeX/docker-php-nginx>

## Requirements

Kubernetes: `>=1.16.0-0`

## Dependencies

| Repository | Name | Version |
|------------|------|---------|
| https://library-charts.k8s-at-home.com | common | 4.4.2 |

## TL;DR

```console
helm repo add k8s-at-home https://k8s-at-home.com/charts/
helm repo update
helm install nginx-php k8s-at-home/nginx-php
```

## Installing the Chart

To install the chart with the release name `nginx-php`

```console
helm install nginx-php k8s-at-home/nginx-php
```

## Uninstalling the Chart

To uninstall the `nginx-php` deployment

```console
helm uninstall nginx-php
```

The command removes all the Kubernetes components associated with the chart **including persistent volumes** and deletes the release.

## Configuration

Read through the [values.yaml](./values.yaml) file. It has several commented out suggested values.
Other values may be used from the [values.yaml](https://github.com/k8s-at-home/library-charts/tree/main/charts/stable/common/values.yaml) from the [common library](https://github.com/k8s-at-home/library-charts/tree/main/charts/stable/common).

Specify each parameter using the `--set key=value[,key=value]` argument to `helm install`.

```console
helm install nginx-php \
  --set env.TZ="America/New York" \
    k8s-at-home/nginx-php
```

Alternatively, a YAML file that specifies the values for the above parameters can be provided while installing the chart.

```console
helm install nginx-php k8s-at-home/nginx-php -f values.yaml
```

## Custom configuration

There are keys in this charts yaml that allows the user to overwrite the following config files in the container.  This allows for control over:

* Nginx configuration (/etc/nginx/conf.d/server.conf)
* PHP configuration (/etc/php8/conf.d/settings.ini)
* PHP-FPM configuration (/etc/php8/php-fpm.d/server.conf)

And can be found under `config:` in this charts [values.yaml](values.yaml)
```yaml
config:
  nginx-server.conf: {}

  php-settings.ini: {}

  php-fpm-server.conf: {}
```

This is achieved in the helm chart by creating a configmap, which is then mounted to the file locations in the pod.

An example of using this feature would be adding the following to your `values.yaml`
```yaml
config:
  nginx-server.conf: |
    [Date]
    date.timezone="Australia/Melbourne"
```

The defauls for these files can be found at [https://github.com/TrafeX/docker-php-nginx/tree/master/config](https://github.com/TrafeX/docker-php-nginx/tree/master/config)

## Values

**Important**: When deploying an application Helm chart you can add more values from our common library chart [here](https://github.com/k8s-at-home/library-charts/tree/main/charts/stable/common)

| Key | Type | Default | Description |
|-----|------|---------|-------------|
| config | object | See https://github.com/TrafeX/docker-php-nginx/tree/master/config for defaults | Overwrites default config files for nginx or php/php-fpm if enabled. |
| env | object | See below | environment variables. See more environment variables in the [nginx-php documentation](https://nginx-php.org/docs). |
| env.TZ | string | `"UTC"` | Set the container timezone |
| image.pullPolicy | string | `"IfNotPresent"` | image pull policy |
| image.repository | string | `"trafex/php-nginx"` | image repository |
| image.tag | string | chart.appVersion | image tag |
| ingress.main | object | See values.yaml | Enable and configure ingress settings for the chart under this key. |
| persistence | object | See values.yaml | Configure persistence settings for the chart under this key. |
| service | object | See values.yaml | Configures service settings for the chart. |

## Changelog

### Version 1.1.2

#### Added

N/A

#### Changed

* Upgraded `common` chart dependency to version 4.4.2

#### Fixed

N/A

### Older versions

A historical overview of changes can be found on [ArtifactHUB](https://artifacthub.io/packages/helm/k8s-at-home/nginx-php?modal=changelog)

## Support

- See the [Docs](https://docs.k8s-at-home.com/our-helm-charts/getting-started/)
- Open an [issue](https://github.com/k8s-at-home/charts/issues/new/choose)
- Ask a [question](https://github.com/k8s-at-home/organization/discussions)
- Join our [Discord](https://discord.gg/sTMX7Vh) community

----------------------------------------------
Autogenerated from chart metadata using [helm-docs v0.1.1](https://github.com/k8s-at-home/helm-docs/releases/v0.1.1)
